{% include "head.html" %}

<h2>Profile</h2>

<table>
<tr>
  <td><b>Name:</b></td>
  <td>{{ data.profile.context.name }}</td>
</tr>
<tr>
  <td><b>Email:</b></td>
  <td>{{ data.profile.context.email }}</td>
</tr>
<tr>
  <td><b>Repo:</b></td>
  <td><a href="https://{{ data.profile.context.git_provider }}.com/{{ data.profile.context.config_repo }}">{{ data.profile.context.config_repo }}</a></td>
</tr>
</table>

{% include "tail.html" %}
